#
# spec file for package ghc-hslua-module-text
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name hslua-module-text
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.1.1
Release:        1.12
Summary:        Lua module for text
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-hslua-core-devel
BuildRequires:  ghc-hslua-core-prof
BuildRequires:  ghc-hslua-marshalling-devel
BuildRequires:  ghc-hslua-marshalling-prof
BuildRequires:  ghc-hslua-packaging-devel
BuildRequires:  ghc-hslua-packaging-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-lua-devel
BuildRequires:  ghc-tasty-lua-prof
BuildRequires:  ghc-tasty-prof
%endif

%description
UTF-8 aware subset of Lua's `string` module.

This package is part of HsLua, a Haskell framework built around the embeddable
scripting language <https://lua.org Lua>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu Jan 18 2024 Peter Simons <psimons@suse.com>
- Update hslua-module-text to version 1.1.1.
  [#]# hslua-module-text-1.1.1
  Released 2024-01-18.
  - Relaxed upper bound for text, allowing text-2.1.
* Thu Apr 13 2023 Peter Simons <psimons@suse.com>
- Update hslua-module-text to version 1.1.0.1.
  [#]# hslua-module-text-1.1.0.1
  Released 2023-03-26.
  - Improved doc strings.
  [#]# hslua-module-text-1.1.0
  Released 2023-03-13.
  - Update to hslua-2.3; this includes the addition of type
    initializers to the module and type specifiers to the fields.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Fri Jan  6 2023 Peter Simons <psimons@suse.com>
- Update hslua-module-text to version 1.0.3.1.
  [#]# hslua-module-text-1.0.3.1
  Released 2023-01-06.
  - Generalized a test to avoid failures with stack nightly.
  - Added GHC 9.4 to test matrix.
* Tue Jan  3 2023 Peter Simons <psimons@suse.com>
- Update hslua-module-text to version 1.0.3.
  [#]# hslua-module-text-1.0.3
  Released 2023-01-03.
  - Added new functions `fromencoding` and `toencoding`. These can
    be used to convert from or to a different (non UTF-8)
    encoding. This is particularly helpful when opening files on
    system that don't use UTF-8 for their file system, most
    notably Windows.
* Sat Feb 19 2022 Peter Simons <psimons@suse.com>
- Update hslua-module-text to version 1.0.2.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/hslua-module-text-1.0.2/src/CHANGELOG.md
* Sun Jan 30 2022 Peter Simons <psimons@suse.com>
- Update hslua-module-text to version 1.0.1 revision 1.
  Upstream has renamed and modified the change log file(s) in this
  release. Unfortunately, the automatic updater cannot reliable
  determine relevant entries for this release.
* Mon Nov  1 2021 psimons@suse.com
- Update hslua-module-text to version 1.0.0.
  [#]# 1.0.0
  Release pending.
  - Use hslua 2.0.
* Tue Oct 19 2021 psimons@suse.com
- Update hslua-module-text to version 0.3.0.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Sat Oct 17 2020 psimons@suse.com
- Update hslua-module-text to version 0.3.0.1.
  [#]# 0.3.0.1 -- 2020-10-16
  - Relaxed upper bound for hslua, allow `hslua-1.3.*`.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Sun Aug 16 2020 psimons@suse.com
- Update hslua-module-text to version 0.3.0.
  [#]# 0.3.0 -- 2020-08-15
  - Use self-documenting module. This allows to include
    documentation with the module definition, and to auto-generate
    documentation from that. Requires hslua-1.2.0 or newer.
  - Run CI tests with all GHC 8 versions, test stack builds.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Sun May  5 2019 psimons@suse.com
- Update hslua-module-text to version 0.2.1.
  [#]# 0.2.1 -- 2019-05-04
  - Require at least HsLua v1.0.3: that version has better support
    for modules.
  - Rename `pushModuleText` to `pushModule`. The old name is keeped
    as an alias for now.
* Wed Oct 10 2018 psimons@suse.com
- Update hslua-module-text to version 0.2.0.
  [#]# 0.2.0 -- 2018-09-24
  - Use hslua 1.0.
  [#]# 0.1.2.2  -- 2018-03-09
  - Relax upper bound for base.
* Mon May 14 2018 psimons@suse.com
- Add hslua-module-text at version 0.1.2.1.
